'''
$ python minmax.py data/table1.csv data/minmax1.csv
>>> run("python minmax.py data/table1.csv data/minmax1.csv")  # doctest: +NORMALIZE_WHITESPACE

Srovnání s očekávaným výstupním souborem:
>>> diff("data/minmax1-expected.csv", "data/minmax1.csv")
True

$ python minmax.py data/table2.csv data/minmax2.csv --header --delimiter ';'
>>> run("python minmax.py data/table2.csv data/minmax2.csv --header --delimiter ';'")  # doctest: +NORMALIZE_WHITESPACE

Srovnání s očekávaným výstupním souborem:
>>> diff("data/minmax2-expected.csv", "data/minmax2.csv")
True
'''


import sys
import contextlib
import argparse


def main() -> None:
    # Načtení argumentů z příkazového řádku pomocí argparse
    parser = argparse.ArgumentParser(description='Calculate minimum and maximum of each column.')
    parser.add_argument('input', help='Input CSV file', type=str)
    parser.add_argument('output', help='Output CSV file', type=str)
    parser.add_argument('-H', '--header', help='Interpret the first line as column names', action='store_true')
    parser.add_argument('-d', '--delimiter', help='Delimiter in the CSV files', type=str, default=',')
    args = parser.parse_args()

    # Následující řádky nahraďte řešením
    print('args.input:', args.input)
    print('args.output:', args.output)
    print('args.header:', args.header)
    print('args.delimiter:', args.delimiter)


def run(command: str) -> None:
    '''Pomocná funkce pro doctesty - neměňte!'''
    def unquote(s: str) -> str:
        return s[1:-1] if s[0]==s[-1] and s[0] in '\'"' else s
    sys.argv = [unquote(s) for s in command.split()[1:]]
    with contextlib.redirect_stderr(sys.stdout), contextlib.suppress(SystemExit):
        main()

def diff(file1: str, file2: str) -> bool:
    '''Pomocná funkce pro doctesty - neměňte!'''
    import difflib
    with open(file1, encoding='utf8') as f:
        lines1 = [line.rstrip() for line in f if line.rstrip() != ''] 
    with open(file2, encoding='utf8') as f:
        lines2 = [line.rstrip() for line in f if line.rstrip() != '']
    d = list(difflib.ndiff(lines1, lines2))
    success = all(line.startswith(' ') for line in d)
    if not success:
        print('Files are different:')
        print('\n'.join(d))
    return success



if __name__ == '__main__':
    main()